@@ -291,10 +291,6 @@ class ChangeFolderColorBase(object):
 class ChangeColorFolder(ChangeFolderColorBase, GObject.GObject, Caja.MenuProvider):
     def __init__(self):
         logger.info("Initializing folder-color-switcher extension...")
-        locale.setlocale(locale.LC_ALL, '')
-        gettext.bindtextdomain('folder-color-switcher')
-        gettext.textdomain('folder-color-switcher')
-
         self.SEPARATOR = u'\u2015' * 4
         self.settings = Gio.Settings.new("org.mate.interface")
         self.settings.connect("changed::icon-theme", self.on_theme_changed)
@@ -315,6 +311,10 @@ class ChangeColorFolder(ChangeFolderColorBase, GObject.GObject, Caja.MenuProvide
             # No items selected
             return
 
+        locale.setlocale(locale.LC_ALL, '')
+        gettext.bindtextdomain('folder-color-switcher')
+        gettext.textdomain('folder-color-switcher')
+
         paths = []
         for item in items_selected:
             # Only folders
@@ -337,7 +337,7 @@ class ChangeColorFolder(ChangeFolderColorBase, GObject.GObject, Caja.MenuProvide
         supported_colors = self.theme.get_supported_colors(paths)
 
         if supported_colors:
-            top_menuitem = Caja.MenuItem(name='ChangeFolderColorMenu::Top', label=_("Change color"), tip='', icon='')
+            top_menuitem = Caja.MenuItem(name='ChangeFolderColorMenu::Top', label=_("Change color"))
             submenu = Caja.Menu()
             top_menuitem.set_submenu(submenu)
 
